'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-4fcc0a9b.js');
const utils = require('./utils-ea4b6a17.js');
const dataTestIds_enum = require('./dataTestIds.enum-990138b0.js');
const signTransactionsModalStore = require('./signTransactionsModalStore-0e1343af.js');

const signTransactionComponentCss = "* {\n  margin: 0;\n  padding: 0;\n  box-sizing: border-box;\n}\n\n.transaction-container {\n  display: flex;\n  flex-direction: column;\n  padding: 0rem 1rem 0rem 1rem;\n  gap: 1rem;\n}\n\n.receiver-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-content-container {\n  display: block;\n  width: 100%;\n  min-height: 100px;\n  height: 100px;\n  border: 1px solid #ccc;\n  border-radius: 4px;\n  padding: 8px;\n  overflow-y: auto;\n  font-family: inherit;\n  font-size: inherit;\n  background-color: #f9f9f9;\n  white-space: pre-wrap;\n  word-wrap: break-word;\n  color: #333;\n}\n\n.data-content {\n  opacity: 0.6;\n}\n\n.fee-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.sign-button-container {\n  display: flex;\n  flex-direction: column;\n}\n\n.sign-back-button {\n  display: inline-block;\n  padding: 8px 12px;\n  background-color: transparent;\n  color: #1a56db;\n  border: none;\n  border-radius: 4px;\n  cursor: pointer;\n  text-decoration: none;\n  font-size: 16px;\n\n  &:hover {\n    text-decoration: underline;\n    color: #0033a0;\n  }\n\n  &:active {\n    color: #001f70;\n  }\n\n  &:disabled {\n    color: #a1a1a1;\n    cursor: not-allowed;\n    text-decoration: none;\n    opacity: 0.6;\n  }\n}\n\n.sign-button {\n  display: block;\n  width: 200px;\n  margin: 0 auto;\n  padding: 12px;\n  background-color: #1a56db;\n  color: white;\n  border: none;\n  border-radius: 8px;\n  cursor: pointer;\n\n  &:disabled {\n    background-color: #a1a1a1;\n    color: #e0e0e0;\n    cursor: not-allowed;\n    opacity: 0.6;\n    box-shadow: none;\n    transform: none;\n  }\n}\n\n.highlight {\n  opacity: 1;\n}\n";
const SignTransactionComponentStyle0 = signTransactionComponentCss;

var __rest = (undefined && undefined.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
const SignTransaction = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    getSignButtonProps() {
        const { currentIndex, nextUnsignedTxIndex } = signTransactionsModalStore.state.commonData;
        if (currentIndex === nextUnsignedTxIndex) {
            return {
                signText: 'Sign',
                disabled: signTransactionsModalStore.state.isWaitingForSignature,
                'data-testid': dataTestIds_enum.DataTestIdsEnum.signTransactionBtn,
                onClick: signTransactionsModalStore.state.onSign
            };
        }
        return {
            signText: 'Next',
            disabled: false,
            'data-testid': dataTestIds_enum.DataTestIdsEnum.signNextTransactionBtn,
            onClick: signTransactionsModalStore.state.onNext
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = signTransactionsModalStore.state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': dataTestIds_enum.DataTestIdsEnum.signCancelBtn,
                backButtonText: 'Cancel',
                onClick: signTransactionsModalStore.state.onCancel
            };
        }
        return {
            'data-testid': dataTestIds_enum.DataTestIdsEnum.signBackBtn,
            backButtonText: 'Back',
            onClick: signTransactionsModalStore.state.onPrev,
            disabled: signTransactionsModalStore.state.isWaitingForSignature
        };
    }
    getHighlightedData() {
        const { data, highlight } = signTransactionsModalStore.state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (index.h("span", null, parts.map((part, index$1) => (index.h("span", null, index.h("span", { class: "data-content" }, part), index$1 < parts.length - 1 && (index.h("span", { class: "highlight" }, highlight)))))));
    }
    render() {
        const { receiver, egldLabel, feeInFiatLimit, feeLimit, scCall } = signTransactionsModalStore.state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (index.h("div", { key: '7026fc2fb8286360dcd6d17a39604850a23a546f', class: "transaction-container" }, this.header, index.h("div", { key: 'f99db4f1168ae9cf6278c3171041cb95ac4854f5', class: "receiver-container" }, index.h("p", { key: 'fd0e59b3b3cabdc31b070e188870ae026a91176d' }, "To"), index.h("p", { key: '6f478e4fe43e87a9c63374909f28f0d2fe332acc' }, utils.formatAddress(receiver, 40))), index.h("div", { key: '796c988eafb9f47e062a3f384a8c3a139b445d8b', class: "fee-container" }, index.h("p", { key: 'b6a8fa78e14392a2ea3ac28442c3d250b9bba07a' }, "Transaction fee"), feeLimit && (index.h("p", { key: '957c14df7af561a44a449d59bda1bf543a4700ae' }, index.h("span", { key: 'c77f3187d75ef361b8a19d08c8b14f7bbd94135f' }, feeLimit), "\u00A0", index.h("span", { key: '524f136ff2916c938c559d94ad725334dc448d66' }, egldLabel))), index.h("p", { key: '374df6330d4e047c767f8f034e09d8d252e83433' }, "\u2248", feeInFiatLimit)), scCall && (index.h("div", { key: 'ddb0d4d0f67c83f5a5a13f3b06e1c673600f2acb', class: "data-container" }, index.h("p", { key: '4e8071c97df74965de8fd1386fcd88358b9e1eb4' }, "Smart Contract Call"), index.h("div", { key: 'c88a6c25981c56b4f93cabef4b6cae8da33c4138', class: "data-content-container" }, scCall))), index.h("div", { key: '5ddc35753fe746bf1fba8fdb1b74b27bd92b9b73', class: "data-container" }, index.h("p", { key: '6cb465769710711c75e9b4fd5cecd7fd7ca9872f' }, "Data"), index.h("div", { key: '6832718ca76ead04bd25feb128ad72b988c7ffe9', class: "data-content-container" }, highlightedData)), index.h("div", { key: 'fb0269dc0a353e2668714c91be5e9d9514dc24b9', class: "sign-button-container" }, index.h("button", Object.assign({ key: '15a0983352e8e0a803204757e5e0c0ffc89bf21d', class: "sign-button" }, signButtonProps), signText), backButtonText && (index.h("button", Object.assign({ key: '6f531ccc1cb6fce80309edc4431063682b5304fa', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
};
SignTransaction.style = SignTransactionComponentStyle0;

exports.sign_transaction_component = SignTransaction;

//# sourceMappingURL=sign-transaction-component.cjs.entry.js.map