var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { h } from "@stencil/core";
import { formatAddress } from "../../../../utils/utils";
import { DataTestIdsEnum } from "../../../../constants/dataTestIds.enum";
import state from "../../signTransactionsModalStore";
export class SignTransaction {
    getSignButtonProps() {
        const { currentIndex, nextUnsignedTxIndex } = state.commonData;
        if (currentIndex === nextUnsignedTxIndex) {
            return {
                signText: 'Sign',
                disabled: state.isWaitingForSignature,
                'data-testid': DataTestIdsEnum.signTransactionBtn,
                onClick: state.onSign
            };
        }
        return {
            signText: 'Next',
            disabled: false,
            'data-testid': DataTestIdsEnum.signNextTransactionBtn,
            onClick: state.onNext
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': DataTestIdsEnum.signCancelBtn,
                backButtonText: 'Cancel',
                onClick: state.onCancel
            };
        }
        return {
            'data-testid': DataTestIdsEnum.signBackBtn,
            backButtonText: 'Back',
            onClick: state.onPrev,
            disabled: state.isWaitingForSignature
        };
    }
    getHighlightedData() {
        const { data, highlight } = state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (h("span", null, parts.map((part, index) => (h("span", null, h("span", { class: "data-content" }, part), index < parts.length - 1 && (h("span", { class: "highlight" }, highlight)))))));
    }
    render() {
        const { receiver, egldLabel, feeInFiatLimit, feeLimit, scCall } = state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (h("div", { key: '7026fc2fb8286360dcd6d17a39604850a23a546f', class: "transaction-container" }, this.header, h("div", { key: 'f99db4f1168ae9cf6278c3171041cb95ac4854f5', class: "receiver-container" }, h("p", { key: 'fd0e59b3b3cabdc31b070e188870ae026a91176d' }, "To"), h("p", { key: '6f478e4fe43e87a9c63374909f28f0d2fe332acc' }, formatAddress(receiver, 40))), h("div", { key: '796c988eafb9f47e062a3f384a8c3a139b445d8b', class: "fee-container" }, h("p", { key: 'b6a8fa78e14392a2ea3ac28442c3d250b9bba07a' }, "Transaction fee"), feeLimit && (h("p", { key: '957c14df7af561a44a449d59bda1bf543a4700ae' }, h("span", { key: 'c77f3187d75ef361b8a19d08c8b14f7bbd94135f' }, feeLimit), "\u00A0", h("span", { key: '524f136ff2916c938c559d94ad725334dc448d66' }, egldLabel))), h("p", { key: '374df6330d4e047c767f8f034e09d8d252e83433' }, "\u2248", feeInFiatLimit)), scCall && (h("div", { key: 'ddb0d4d0f67c83f5a5a13f3b06e1c673600f2acb', class: "data-container" }, h("p", { key: '4e8071c97df74965de8fd1386fcd88358b9e1eb4' }, "Smart Contract Call"), h("div", { key: 'c88a6c25981c56b4f93cabef4b6cae8da33c4138', class: "data-content-container" }, scCall))), h("div", { key: '5ddc35753fe746bf1fba8fdb1b74b27bd92b9b73', class: "data-container" }, h("p", { key: '6cb465769710711c75e9b4fd5cecd7fd7ca9872f' }, "Data"), h("div", { key: '6832718ca76ead04bd25feb128ad72b988c7ffe9', class: "data-content-container" }, highlightedData)), h("div", { key: 'fb0269dc0a353e2668714c91be5e9d9514dc24b9', class: "sign-button-container" }, h("button", Object.assign({ key: '15a0983352e8e0a803204757e5e0c0ffc89bf21d', class: "sign-button" }, signButtonProps), signText), backButtonText && (h("button", Object.assign({ key: '6f531ccc1cb6fce80309edc4431063682b5304fa', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
    static get is() { return "sign-transaction-component"; }
    static get originalStyleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get properties() {
        return {
            "header": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "VNode",
                    "resolved": "VNode",
                    "references": {
                        "VNode": {
                            "location": "import",
                            "path": "@stencil/core",
                            "id": "node_modules::VNode"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
}
//# sourceMappingURL=sign-transaction-component.js.map
